@@ -3,7 +3,7 @@ from pydantic import BaseModel
 from odin_messages.base import BaseEventMessage
 
 
-class PriceWatchMesagge(BaseEventMessage):
+class PriceWatchMessage(BaseEventMessage):
     exchange: str
     market_code: str
     ask_price: float
